# Emoji Integration Test Page

This page is used for integration testing and is not linked in the navigation.

## Slack Emojis

:partyparrot: :slack-partyparrot:

:shipit: :slack-shipit:

## Discord Emojis

:meow_party: :discord-meow_party:

:stonks: :discord-stonks:

## Misc

:unresolved-emoji:
